@@ -18,11 +18,17 @@
 # under the License.
 
 from aliyunsdkcore.request import RpcRequest
+from aliyunsdkimageseg.endpoint import endpoint_data
 
 class SegmentCommonImageRequest(RpcRequest):
 
 	def __init__(self):
 		RpcRequest.__init__(self, 'imageseg', '2019-12-30', 'SegmentCommonImage','imageseg')
+		if hasattr(self, "endpoint_map"):
+			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
+		if hasattr(self, "endpoint_regional"):
+			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
+
 
 	def get_ImageURL(self):
 		return self.get_query_params().get('ImageURL')
